import QtQuick 1.1
import qb.components 1.0
import ImagePixelReader 1.0

Screen {
	id: buienradarStationScreen
	screenTitle: "Selecteer weerstation";
	isSaveCancelDialog: true
	property int offsetX: 68
	property int offsetY: 76
	property string activeProvince
	property alias zeelandImageVisible: zeelandImage.visible
	property alias utrechtImageVisible: utrechtImage.visible
	property alias gelderlandImageVisible: gelderlandImage.visible

	property variant provincies: {
		"#23922d": {'img': zeelandImage, 'name': "zeeland"},
		"#b9cc33": {'img': zuidhollandImage, 'name': "zuidholland"},
		"#f0c4f" : {'img': noordhollandImage, 'name': "noordholland"},
		"#d21242": {'img': frieslandImage, 'name': "friesland"},
		"#85d93e": {'img': groningenImage, 'name': "groningen"},
		"#f39c12": {'img': drentheImage, 'name': "drenthe"},
		"#e74b3b": {'img': overijsselImage, 'name': "overijssel"},
		"#c599ff": {'img': gelderlandImage, 'name': "gelderland"},
		"#5da9d4": {'img': utrechtImage, 'name': "utrecht"},
		"#f14688": {'img': noordbrabantImage, 'name': "noordbrabant"},
		"#6868aa": {'img': limburgImage, 'name': "limburg"},
		"#238195": {'img': flevolandImage, 'name': "flevoland"},
		"#000": false
	}

	QtObject {
		id: p

		property string activeProvinceShortName
	}

	function setSelectedProvince() {
//		if (provincies[activeProvince])
//			provincies[activeProvince].img.visible = false;
//		provincies[location2province[app.location]].img.visible = true;
//		activeProvince = location2province[app.location];
//		p.activeProvinceShortName = provincies[location2province[app.location]].name;
//		provinceItem.selectDefault(p.activeProvinceShortName, app.locationId);
	}

	function init() {
//		app.locationIdChanged.connect(setSelectedProvince);
		provinceItem.init();
	}

	function picProvince(x, y) {
		var activeProvinceNew = pixelReader.getPixel(x, y);
		if (provincies[activeProvinceNew]) {
			if (activeProvince)
				provincies[activeProvince].img.visible = false;
			provincies[activeProvinceNew].img.visible = true;
			activeProvince = activeProvinceNew;
			p.activeProvinceShortName = provincies[activeProvinceNew].name;
			provinceItem.showProvince(p.activeProvinceShortName);
		}
	}

	function getProvinceName(shortName) {
		switch (shortName) {
			case "zuidholland": return qsTr("Zuid-Holland");
			case "noordholland": return qsTr("Noord-Holland");
			case "zeeland": return qsTr("Zeeland");
			case "groningen": return qsTr("Groningen");
			case "drenthe": return qsTr("Drenthe");
			case "overijssel": return qsTr("Overijssel");
			case "gelderland": return qsTr("Gelderland");
			case "utrecht": return qsTr("Utrecht");
			case "noordbrabant": return qsTr("Noord-Brabant");
			case "limburg": return qsTr("Limburg");
			case "flevoland": return qsTr("Flevoland");
			case "friesland": return qsTr("Friesland");
			default: break;
		}
		return "";
	}

	function getlocationName(locid) {
		switch (locid) {
			case "6391" : return "Arcen";
			case "6275" : return "Arnhem";
			case "6249" : return "Berkhout";
		case "6308" : return "Cadzand";
			case "6260" : return "De Bilt";
			case "6235" : return "Den Helder";
			case "6370" : return "Eindhoven";
			case "6377" : return "Ell";
			case "6321" : return "Euro platform";	
			case "6350" : return "Gilze Rijen";
		case "6283" : return "Groenlo";
			case "6280" : return "Groningen";
		case "6315" : return "Hansweert";
			case "6278" : return "Heino";
			case "6356" : return "Herwijnen";
			case "6330" : return "Hoek v Holland";
			case "6279" : return "Hoogeveen";
			case "6251" : return "Terschelling";
		case "6258" : return "Houtribdijk";
		case "6285" : return "Schiermonnikoog";
		case "6209" : return "IJmond";
		case "6225" : return "IJmuiden";
			case "6277" : return "Lauwersoog";
		case "6320" : return "Goeree";
			case "6270" : return "Leeuwarden";
			case "6269" : return "Lelystad";
			case "6348" : return "Lopik-Cabauw";
			case "6380" : return "Maastricht";
			case "6273" : return "Marknesse";
			case "6286" : return "Nieuw Beerta";
		case "6312" : return "Oosterschelde";
			case "6344" : return "Rotterdam";
		case "6316" : return "Schaar";
			case "6240" : return "Schiphol";
		case "6324" : return "Stavenisse";
			case "6267" : return "Stavoren";
		case "6331" : return "Tholen";
			case "6290" : return "Twente";
		case "6313" : return "Vlakte ad Raan";
			case "6242" : return "Vlieland";
			case "6310" : return "Vlissingen";
			case "6375" : return "Volkel";
		case "6215" : return "Voorschoten";
			case "6319" : return "Westdorpe";
		case "6248" : return "Wijdenes";
		case "6257" : return "Wijk aan Zee";
			case "6340" : return "Woensdrecht";
			default: break;
		}
		return "";
	}

	onShown: {
		screenStateController.screenColorDimmedIsReachable = false;
	}

	onHidden: {
		screenStateController.screenColorDimmedIsReachable = true;
	}

	onSaved: {
		app.location = provinceItem.selectedStationId.toString();
		app.updateBuienradar();
   		var doc2 = new XMLHttpRequest();
   		doc2.onreadystatechange = function() {
       		if (doc2.readyState == XMLHttpRequest.DONE) {
      				// output response of request
      				console.log(doc2.status);
       		}
   		}
   		doc2.open("PUT", "file:///HCBv2/qml/apps/buienradar/selectedStation.txt");
   		doc2.send(provinceItem.selectedStationId.toString());
	}

	onCanceled: {
		if (activeProvince)
			provincies[activeProvince].img.visible = false;
		setSelectedProvince();
	}

	ImagePixelReader {
		id: pixelReader
		imageUrl: "../weather/drawables/provincies/nederlandcolourfullClickAreas.png"
	}

	Text {
		id: chooseProvinceText
		color: colors.waSystemState
		font {
			pixelSize: 20
			family: qfont.semiBold.name
		}
		anchors {
			baseline: parent.top
			left: parent.left
			baselineOffset: 60
			leftMargin: 68
		}
		text: qsTr("Selecteer uw provincie")
	}

	Image {
		id: dutchMapImage
		source: "../weather/drawables/provincies/nederland.png"
		anchors {
			top: chooseProvinceText.baseline
			topMargin: 15
			left: parent.left
			leftMargin: 68
		}
		cache: false

		MouseArea {
			id: dutchMapMouseArea
			anchors.fill: parent
			onClicked: picProvince(mouseX, mouseY)
			property string kpiPostfix: "provinceSelect"
		}
	}
	Image {
		id: drentheImage
		source: "../weather/drawables/provincies/tinydrenthe.png"
		visible: false
		x: offsetX + 184
		y: offsetY + 42
		cache: false
	}
	Image {
		id: flevolandImage
		source: "../weather/drawables/provincies/tinyflevoland.png"
		visible: false
		x: offsetX + 119
		y: offsetY + 84
		cache: false
	}
	Image {
		id: frieslandImage
		source: "../weather/drawables/provincies/tinyfriesland.png"
		visible: false
		x: offsetX + 99
		y: offsetY + 5
		cache: false
	}
	Image {
		id: gelderlandImage
		source: "../weather/drawables/provincies/tinygelderland.png"
		visible: false
		x: offsetX + 110
		y: offsetY + 122
		cache: false
	}
	Image {
		id: groningenImage
		source: "../weather/drawables/provincies/tinygroningen.png"
		visible: false
		x: offsetX + 186
		y: offsetY
	}
	Image {
		id: limburgImage
		source: "../weather/drawables/provincies/tinylimburg.png"
		visible: false
		x: offsetX + 159
		y: offsetY + 205
		cache: false
	}
	Image {
		id: noordbrabantImage
		source: "../weather/drawables/provincies/tinynoordbrabant.png"
		visible: false
		x: offsetX + 52
		y: offsetY + 201
		cache: false
	}
	Image {
		id: noordhollandImage
		source: "../weather/drawables/provincies/tinynoordholland.png"
		visible: false
		x: offsetX + 77
		y: offsetY + 45
		cache: false
	}
	Image {
		id: overijsselImage
		source: "../weather/drawables/provincies/tinyoverijssel.png"
		visible: false
		x: offsetX + 163
		y: offsetY + 82
		cache: false
	}
	Image {
		id: utrechtImage
		source: "../weather/drawables/provincies/tinyutrecht.png"
		visible: false
		x: offsetX + 99
		y: offsetY + 146
		cache: false
	}
	Image {
		id: zeelandImage
		source: "../weather/drawables/provincies/tinyzeeland.png"
		visible: false
		x: offsetX + 1
		y: offsetY + 214
		cache: false
	}
	Image {
		id: zuidhollandImage
		source: "../weather/drawables/provincies/tinyzuidholland.png"
		visible: false
		x: offsetX + 33
		y: offsetY + 145
		cache: false
	}

	Text {
		id: chooseStationText
		color: colors.waSystemState
		font {
			pixelSize: 20
			family: qfont.semiBold.name
		}
		anchors {
			left: dutchMapImage.right
			leftMargin: 68
			baseline: parent.top
			baselineOffset: 60
		}
		text: qsTr("Kies uw weerstation in:\n%1").arg(getProvinceName(p.activeProvinceShortName))
	}

	BuienradarStationProvince {
		id: provinceItem

		width: parent.width
		//+10 for the screen footer - the desing values for vertical positions includes the footer
		height: parent.height + 10;
	}
}
